@@ -10,6 +10,7 @@ var (
 
 var commands []*cli.Command = []*cli.Command{
 	filterCommand(),
+	searchCommand(),
 	histogramCommand(),
 	heatmapCommand(),
 	sparkCommand(),
@@ -19,6 +20,7 @@ var commands []*cli.Command = []*cli.Command{
 	reduceCommand(),
 	docsCommand(),
 	expressionCommand(),
+	walkCommand(),
 }
 
 func GetSupportedCommands() []*cli.Command {
