@@ -4,6 +4,7 @@ import (
 	"testing"
 
 	"github.com/stretchr/testify/assert"
+	"github.com/zix99/rare/pkg/testutil"
 )
 
 // Exercise common commands for panics
@@ -21,7 +22,7 @@ func TestHistogram(t *testing.T) {
 func TestHistogramRender(t *testing.T) {
 	out, eout, err := testCommandCapture(histogramCommand(), `--snapshot -m "(\d+)" -e "{bucket {1} 10}" testdata/log.txt`)
 	assert.NoError(t, err)
-	assert.Equal(t, out, "0           2         \n20          1         \n\n\n\nMatched: 3 / 6 (Groups: 2)\n96 B (0 B/s) \n")
+	testutil.AssertPattern(t, out, "0           2         \n20          1         \n\n\n\nMatched: 3 / 6 (Groups: 2)\n96 B in * (*)\n")
 	assert.Equal(t, "", eout)
 }
 
