@@ -22,7 +22,7 @@ func kfColor(args []KeyBuilderStage) (KeyBuilderStage, error) {
 
 	colorCode, hasColor := color.LookupColorByName(colorName)
 	if !hasColor {
-		return stageArgError(ErrEnum, 0)
+		return stageArgErrorf(ErrEnum, 0, "invalid color, options: "+strings.Join(color.AvailableColorNames(), ", "))
 	}
 
 	return KeyBuilderStage(func(context KeyBuilderContext) string {
@@ -68,9 +68,9 @@ func kfBar(args []KeyBuilderStage) (KeyBuilderStage, error) {
 	scaler := termscaler.ScalerLinear
 	if len(args) >= 4 {
 		if name, ok := EvalStaticStage(args[3]); ok {
-			var scalerOk bool
-			if scaler, scalerOk = termscaler.ScalerByName(name); !scalerOk {
-				return stageArgError(ErrEnum, 3)
+			var scalerErr error
+			if scaler, scalerErr = termscaler.ScalerByName(name); scalerErr != nil {
+				return stageArgErrorf(ErrEnum, 3, scalerErr)
 			}
 		} else {
 			return stageArgError(ErrConst, 3)
