@@ -4,14 +4,14 @@ import (
 	"io"
 )
 
-func OpenReaderToChan(sourceName string, reader io.ReadCloser, batchSize, batchBuffer int) *Batcher {
+func OpenReaderToChan(sourceName string, reader io.ReadCloser, batchSize, batchBuffer, readBufSize int) *Batcher {
 	out := newBatcher(batchBuffer)
 
 	go func() {
 		defer reader.Close()
 		defer out.close()
 		out.startFileReading(sourceName)
-		out.syncReaderToBatcherWithTimeFlush(sourceName, reader, batchSize, AutoFlushTimeout)
+		out.syncReaderToBatcherWithTimeFlush(sourceName, reader, batchSize, readBufSize, AutoFlushTimeout)
 		out.stopFileReading(sourceName)
 	}()
 
